@@ -11,7 +11,6 @@ resource_frequency_resource_activity <- function(eventlog) {
 		group_by(!!resource_id_(eventlog)) %>%
 		mutate(relative_resource = absolute/sum(absolute)) %>%
 		group_by(!!activity_id_(eventlog)) %>%
-		mutate(relative_activity = absolute/sum(absolute)) %>%
-		arrange(-absolute)-> r
+		mutate(relative_activity = absolute/sum(absolute))
 
 }
