@@ -12,6 +12,7 @@ start_activities_resource_activity <- function(eventlog) {
 		ungroup() %>%
 		arrange(desc(absolute)) %>%
 		mutate(relative = absolute/n_cases(eventlog),
-			   cum_sum = cumsum(relative))
+			   cum_sum = cumsum(relative)) %>%
+		arrange(!!resource_id_(eventlog), !!activity_id_(eventlog))
 
 }
